@@ -1,22 +1,15 @@
 from dataclasses import dataclass
-from typing import (
-    Any,
-    Generic,
-    List,
-    MutableMapping,
-    Protocol,
-    TypeAlias,
-    TypeVar,
-    Union,
-)
+from typing import Any, Generic, MutableMapping, Protocol, TypeAlias, TypeVar
 
 T = TypeVar("T")
 
+Props: TypeAlias = MutableMapping[str, Any]
+
 
 @dataclass(slots=True, frozen=True)
 class PatchProps:
-    remove_keys: List[str]
-    add_props: "Props"
+    remove_keys: list[str]
+    add_props: Props
 
 
 @dataclass(slots=True, frozen=True)
@@ -35,7 +28,7 @@ class PatchText:
     value: str
 
 
-Patch = Union[PatchProps, PatchInsertChild, PatchRemoveChild, PatchText]
+Patch = PatchProps | PatchInsertChild | PatchRemoveChild | PatchText
 
 
 class Node(Protocol):
@@ -46,8 +39,8 @@ class Node(Protocol):
 @dataclass(slots=True, frozen=True)
 class Element(Generic[T]):
     tag: str
-    props: "Props"
-    children: List[T]
+    props: Props
+    children: list[T]
 
 
 @dataclass(slots=True, frozen=True)
@@ -55,10 +48,7 @@ class VDomElement(Element["VDom"]):
     ...
 
 
-VDom = Union[VDomElement, str]
-
-
-Props: TypeAlias = MutableMapping[str, Any]
+VDom = VDomElement | str
 
 
 def el(
